DvG_QDeviceIO
===================

*PyQt5 interface for multithreaded periodical data acquisition and communication with an I/O device.*


.. toctree::
   :caption: Introduction

   intro
   example

   
.. toctree::
   :caption: API

   api-qdeviceio
   api-workerdaq
   api-workerjobs
   api-daqtrigger


.. toctree::
   :maxdepth: 1
   :caption: Other

   authors
   changelog
   contributing
   genindex
